diff --git a/.github/trigger_files/IO_Iceberg_Integration_Tests.json b/.github/trigger_files/IO_Iceberg_Integration_Tests.json
index b73af5e61a4314e8788780dabaf43c1e1571fba6..7ab7bcd9a9c6f84dd012a911e131472b6124f251 100644
--- a/.github/trigger_files/IO_Iceberg_Integration_Tests.json
+++ b/.github/trigger_files/IO_Iceberg_Integration_Tests.json
@@ -1,4 +1,4 @@
 {
     "comment": "Modify this file in a trivial way to cause this test suite to run.",
-    "modification": 1
+    "modification": 2
 }
diff --git a/sdks/java/io/iceberg/hive/build.gradle b/sdks/java/io/iceberg/hive/build.gradle
index 7d93a4026775ad8f5167ef3789adb46bb0490844..480707b128b191a1f39bcafb307517492006d6c4 100644
--- a/sdks/java/io/iceberg/hive/build.gradle
+++ b/sdks/java/io/iceberg/hive/build.gradle
@@ -1,5 +1,3 @@
-import groovy.json.JsonOutput
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -32,6 +30,7 @@ def hbase_version = "2.6.1-hadoop3"
 def hadoop_version = "3.4.1"
 def iceberg_version = "1.6.1"
 def avatica_version = "1.25.0"
+def calcite_version = "1.37.0"
 
 dependencies {
     // dependencies needed to run with iceberg's hive catalog
@@ -44,12 +43,26 @@ dependencies {
         exclude group: "org.apache.hadoop", module: "hadoop-yarn-server-resourcemanager"
         // old hadoop-yarn-server-resourcemanager contains critical log4j and hadoop vulneribility
         exclude group: "org.apache.hbase", module: "hbase-client"
         // old calcite leaks old protobuf-java
         exclude group: "org.apache.calcite.avatica", module: "avatica"
+        // old calcite vulnerabilities
+        exclude group: "org.apache.calcite", module: "calcite-core"
+        exclude group: "org.apache.calcite", module: "calcite-druid"
     }
     runtimeOnly ("org.apache.hadoop:hadoop-yarn-server-resourcemanager:$hadoop_version")
     runtimeOnly ("org.apache.hbase:hbase-client:$hbase_version")
     runtimeOnly ("org.apache.calcite.avatica:avatica-core:$avatica_version")
+    // these exlusions were inherit from hive-exec-3.1.3.pom
+    runtimeOnly ("org.apache.calcite:calcite-core:$calcite_version") {
+        exclude group: "net.hydromatic", module: "aggdesigner-algorithm"
+        exclude group: "org.hsqldb", module: "hsqldb"
+        exclude group: "com.fasterxml.jackson.core", module: "*"
+        exclude group: "org.apache.calcite.avatica", module: "avatica-core"
+    }
+    runtimeOnly ("org.apache.calcite:calcite-druid:$calcite_version") {
+        exclude group: "com.fasterxml.jackson.core", module: "*"
+        exclude group: "org.apache.calcite.avatica", module: "avatica-core"
+    }
     runtimeOnly ("org.apache.hive:hive-metastore:$hive_version")
 }
@@ -44,12 +43,26 @@ dependencies {
         // old hadoop-yarn-server-resourcemanager contains critical log4j and hadoop vulneribility
         exclude group: "org.apache.hbase", module: "hbase-client"
-        // old calcite leaks old protobuf-java
+        // old calcite avatica leaks old protobuf-java
         exclude group: "org.apache.calcite.avatica", module: "avatica"